@@ -27,7 +27,7 @@ has pubsub => sub {
   return $pubsub;
 };
 
-our $VERSION = '2.20';
+our $VERSION = '2.21';
 
 sub db {
   my $self = shift;
@@ -146,7 +146,7 @@ Mojo::Pg - Mojolicious ♥ PostgreSQL
   # Select all rows non-blocking
   $db->query('select * from names' => sub {
     my ($db, $err, $results) = @_;
-    say $err and return if $err;
+    die $err if $err;
     say $_->{name} for $results->hashes->each;
   });
   Mojo::IOLoop->start unless Mojo::IOLoop->is_running;
@@ -155,13 +155,13 @@ Mojo::Pg - Mojolicious ♥ PostgreSQL
   Mojo::IOLoop->delay(
     sub {
       my $delay = shift;
-      $pg->db->query('select now()'        => $delay->begin);
+      $pg->db->query('select now() as now' => $delay->begin);
       $pg->db->query('select * from names' => $delay->begin);
     },
     sub {
       my ($delay, $time_err, $time, $names_err, $names) = @_;
       if (my $err = $time_err || $names_err) { die $err }
-      say $time->array->[0];
+      say $time->hash->{now};
       say $_->{name} for $names->hashes->each;
     }
   )->wait;
@@ -185,20 +185,19 @@ L<Mojo::Pg> is a tiny wrapper around L<DBD::Pg> that makes
 L<PostgreSQL|http://www.postgresql.org> a lot of fun to use with the
 L<Mojolicious|http://mojolicious.org> real-time web framework.
 
-Database and statement handles are cached automatically, so they can be reused
-transparently to increase performance. And you can handle connection timeouts
+Database and statement handles are cached automatically, and will be reused
+transparently to increase performance. You can handle connection timeouts
 gracefully by holding on to them only for short amounts of time.
 
   use Mojolicious::Lite;
   use Mojo::Pg;
 
-  helper pg =>
-    sub { state $pg = Mojo::Pg->new('postgresql://sri:s3cret@localhost/db') };
+  helper pg => sub { state $pg = Mojo::Pg->new('postgresql://postgres@/test') };
 
   get '/' => sub {
     my $c  = shift;
     my $db = $c->pg->db;
-    $c->render(json => $db->query('select now() as time')->hash);
+    $c->render(json => $db->query('select now() as now')->hash);
   };
 
   app->start;
@@ -220,6 +219,35 @@ All cached database handles will be reset automatically if a new process has
 been forked, this allows multiple processes to share the same L<Mojo::Pg>
 object safely.
 
+=head1 GROWING
+
+And as your application grows, you can move queries into model classes.
+
+  package MyApp::Model::Time;
+  use Mojo::Base -base;
+
+  has 'pg';
+
+  sub now { shift->pg->db->query('select now() as now')->hash }
+
+  1;
+
+Which get integrated into your application with helpers.
+
+  use Mojolicious::Lite;
+  use Mojo::Pg;
+  use MyApp::Model::Time;
+
+  helper pg => sub { state $pg = Mojo::Pg->new('postgresql://postgres@/test') };
+  helper time => sub { state $time = MyApp::Model::Time->new(pg => shift->pg) };
+
+  get '/' => sub {
+    my $c = shift;
+    $c->render(json => $c->time->now);
+  };
+
+  app->start;
+
 =head1 EVENTS
 
 L<Mojo::Pg> inherits all events from L<Mojo::EventEmitter> and can emit the
