@@ -88,6 +88,13 @@ sub query {
   $self->_watch;
 }
 
+sub tables {
+  shift->query(
+    "select table_schema || '.' || table_name from information_schema.tables
+     where table_schema not in ('pg_catalog', 'information_schema')"
+  )->arrays->map(sub { $_->[0] })->to_array;
+}
+
 sub unlisten {
   my ($self, $name) = @_;
 
@@ -292,6 +299,16 @@ also append a callback to perform operation non-blocking.
   });
   Mojo::IOLoop->start unless Mojo::IOLoop->is_running;
 
+=head2 tables
+
+  my $tables = $db->tables;
+
+Return table names (that are not internal) for this database as an array
+reference.
+
+  # Names of all tables
+  say for @{$db->tables};
+
 =head2 unlisten
 
   $db = $db->unlisten('foo');
@@ -301,6 +318,6 @@ Unsubscribe from a channel, C<*> can be used to unsubscribe from all channels.
 
 =head1 SEE ALSO
 
-L<Mojo::Pg>, L<Mojolicious::Guides>, L<http://mojolicio.us>.
+L<Mojo::Pg>, L<Mojolicious::Guides>, L<http://mojolicious.org>.
 
 =cut
